// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIpPwYJKoZIhvcNAQcCoIIpMDCCKSwCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAA9LaGRZdbcdJrwAA
// SIG // AAAD0jANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTI0MDIyMjIwMjU1MloX
// SIG // DTI1MDIxOTIwMjU1MlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALdqEoU6W4QYwAex/MdHkWVW
// SIG // /KE4Upt5VCyXOoFKiGCkfI4P9VCd0wiGQxD+WK6yL+Eo
// SIG // j/RxpFOy4Q4t/WbiJezoULDKavmxTNRp3z0ZkJfGR5ks
// SIG // YBoM0MItIeAfbqxMuoW6w0q5HncCxJi0x9MJWuhLiQZK
// SIG // VJdlY3Qixxa/PVmBY9PbzPanBhTthMeH03ScbieAeDJc
// SIG // TIbWIyxWrIlawZIwgkkK3bVuJe+tqbNIPKmRSmQWGeDA
// SIG // zkeTzFEehK2YPzHlBleu8yp1Z0a7yecNWh3wl4uxyG62
// SIG // 6YBQQ42xcFhreA5q2VBEgl0nlF24Fa2JVvIDH8Tl2Rtr
// SIG // 3ALpefWetYHsrQd3/JS02w7GR2FKsP0iSlgSbabJCV6B
// SIG // ILmGx/WltmTKxFZw5nuhDaNFkBq4UqEBMRAVEVY8rJ29
// SIG // FgqZjTs5YCTGm+YkjSeRciM+QYahAc6WhaXUCZ0hlWCy
// SIG // WYSc7gg4NbvH02eHPUfgo3UAWkxQGRnL1QG2Gn6XSwju
// SIG // FGud6wIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFANWxir0
// SIG // XadzyHYXZDqQCRDCKO8/MFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys1MDIw
// SIG // ODUwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQClGvcxkigIlw60
// SIG // wWETAB6g+IEscqetgjSH9ndL4Po9vCpGs1Vyzl9Fsa0U
// SIG // 3dUv7kC2DsBSAHvQzF3k0hOdwnvLurkzCYwX8T26TacP
// SIG // UgDTy8IbuNBT+cof4Aj9mnuXk3hkbx/Btha9NGqrHBB/
// SIG // rwEz2Fob1WtCst4VsBFsPnfl0BQ+79IktYTB6HVdZy1p
// SIG // BsIQ1/G2cT3NQwMfbVV/L2Svk9NWPqY+xsfG9LkqbTN0
// SIG // VPme18Xuu5mfjtgO7CgR0OtrenSOiQjcPK8f1DukpddH
// SIG // R/0vzOohFqTtbFs1gF//N3E4K0DFD3vAJAQt6ZXYyCSq
// SIG // +j6uiEZ2Tws6KT1fgqD+RhG04iNTGeG0McH2jXpcDj8o
// SIG // 5hTt971pQq0Qfn1ysPHdCcTaP7pzlvXDHnYmVfgf8Ism
// SIG // p+nfZlgcdUB11k4PVDRkniap54Hdodi8n7bwnKXa2Fjb
// SIG // GrZg7Yy6c5uQHcqG8WZtnMXgwPcZDEAKhqPyE7iMtJrU
// SIG // YVtlsQrP9uPcXi9E7nAFcVJmt1g50MrOmuXfAR6x9TRP
// SIG // c7rpiVQQA15bEBNRGAxvFwzPh8pjRZjXJz7Sj+8JDyJ1
// SIG // WOGejwkUVdgg/bPjz+dX8KQmozKzF/Vd6Npa/vxhF4RS
// SIG // DOfhfbsJbSaYeMjlO7U1lOe51nq4n3BOWFJNnUFMZB4M
// SIG // Fl3zJVHkKzCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghqjMIIanwIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAAD0toZFl1t
// SIG // x0mvAAAAAAPSMA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCD3omjKU+2ltBtHmjuFe7vjmLFCFgQ9lehLg9Wo3349
// SIG // uDBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgJwRV05KItkzV8mS
// SIG // h7DU4h0aJuAhHdKU/r7ZrUMDtdMP4v6LHog50vm6c+g+
// SIG // vhOMNWgOU5/dHu58CeygxRDoQ7kMypYv/PyX61YGCmG/
// SIG // F2D6mx5Z/SZZl3ck8jyqDz8VbVLLQ+HYn9Nq3MSD+vUO
// SIG // lpozQ/uliFptv0bJ69LzItoTCwpgQ3lenUrqZZwWQE3q
// SIG // DB1qmV5ZvM0cnAbQAbLe/TqHkux9YqxbvD0cJcgfVkOZ
// SIG // 3HNF+r5B2mbz6VizZScLwITYpsGBcr3hTl1QVMkua4Co
// SIG // 9kRmrRJji26KncB5KdgFifA+8kmgHFtx4mCCPqX9w+lk
// SIG // wZjFlrDuBgLxE1h5rxwPdB5SDlSsI23edgZJxP6iFUz3
// SIG // OQEhojFJIwwiFt0w8UeiXLSH2yWdQF1ZusbXUqw9MXXN
// SIG // jp4TBweAfScQteJefejuBJQruqlMj/iKXKWyyJf3f9nO
// SIG // pCWot1VRclW8/CsXiM4mQiSCRk7srqoFRCAkKfIEpnNj
// SIG // pUaPBPIHCBNggqGCF60wghepBgorBgEEAYI3AwMBMYIX
// SIG // mTCCF5UGCSqGSIb3DQEHAqCCF4YwgheCAgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFaBgsqhkiG9w0BCRABBKCCAUkE
// SIG // ggFFMIIBQQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCCWE/Ksq9FtHsJiyB7tp1/e4Hm6d59pHQQJ
// SIG // seKXo5yFjgIGZutTMOZWGBMyMDI0MTAyNjAxMzE0MC4y
// SIG // ODZaMASAAgH0oIHZpIHWMIHTMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBP
// SIG // cGVyYXRpb25zIExpbWl0ZWQxJzAlBgNVBAsTHm5TaGll
// SIG // bGQgVFNTIEVTTjo0MzFBLTA1RTAtRDk0NzElMCMGA1UE
// SIG // AxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaCC
// SIG // EfswggcoMIIFEKADAgECAhMzAAAB+vs7RNN3M8bTAAEA
// SIG // AAH6MA0GCSqGSIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVT
// SIG // MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
// SIG // ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
// SIG // YXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0
// SIG // YW1wIFBDQSAyMDEwMB4XDTI0MDcyNTE4MzExMVoXDTI1
// SIG // MTAyMjE4MzExMVowgdMxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // LTArBgNVBAsTJE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJh
// SIG // dGlvbnMgTGltaXRlZDEnMCUGA1UECxMeblNoaWVsZCBU
// SIG // U1MgRVNOOjQzMUEtMDVFMC1EOTQ3MSUwIwYDVQQDExxN
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIICIjAN
// SIG // BgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAyhZVBM3P
// SIG // ZcBfEpAf7fIIhygwYVVP64USeZbSlRR3pvJebva0LQCD
// SIG // W45yOrtpwIpGyDGX+EbCbHhS5Td4J0Ylc83ztLEbbQD7
// SIG // M6kqR0Xj+n82cGse/QnMH0WRZLnwggJdenpQ6UciM4nM
// SIG // YZvdQjybA4qejOe9Y073JlXv3VIbdkQH2JGyT8oB/Lsv
// SIG // PL/kAnJ45oQIp7Sx57RPQ/0O6qayJ2SJrwcjA8auMdAn
// SIG // ZKOixFlzoooh7SyycI7BENHTpkVKrRV5YelRvWNTg1pH
// SIG // 4EC2KO2bxsBN23btMeTvZFieGIr+D8mf1lQQs0Ht/tMO
// SIG // Vdah14t7Yk+xl5P4Tw3xfAGgHsvsa6ugrxwmKTTX1kqX
// SIG // H5XCdw3TVeKCax6JV+ygM5i1NroJKwBCW11Pwi0z/ki9
// SIG // 0ZeO6XfEE9mCnJm76Qcxi3tnW/Y/3ZumKQ6X/iVIJo7L
// SIG // k0Z/pATRwAINqwdvzpdtX2hOJib4GR8is2bpKks04Gur
// SIG // fweWPn9z6jY7GBC+js8pSwGewrffwgAbNKm82ZDFvqBG
// SIG // QQVJwIHSXpjkS+G39eyYOG2rcILBIDlzUzMFFJbNh5tD
// SIG // v3GeJ3EKvC4vNSAxtGfaG/mQhK43YjevsB72LouU78rx
// SIG // tNhuMXSzaHq5fFiG3zcsYHaa4+w+YmMrhTEzD4SAish3
// SIG // 5BjoXP1P1Ct4Va0CAwEAAaOCAUkwggFFMB0GA1UdDgQW
// SIG // BBRjjHKbL5WV6kd06KocQHphK9U/vzAfBgNVHSMEGDAW
// SIG // gBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNVHR8EWDBW
// SIG // MFSgUqBQhk5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
// SIG // cGtpb3BzL2NybC9NaWNyb3NvZnQlMjBUaW1lLVN0YW1w
// SIG // JTIwUENBJTIwMjAxMCgxKS5jcmwwbAYIKwYBBQUHAQEE
// SIG // YDBeMFwGCCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NlcnRzL01pY3Jvc29mdCUy
// SIG // MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNydDAM
// SIG // BgNVHRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUF
// SIG // BwMIMA4GA1UdDwEB/wQEAwIHgDANBgkqhkiG9w0BAQsF
// SIG // AAOCAgEAuFbCorFrvodG+ZNJH3Y+Nz5QpUytQVObOyYF
// SIG // rgcGrxq6MUa4yLmxN4xWdL1kygaW5BOZ3xBlPY7Vpuf5
// SIG // b5eaXP7qRq61xeOrX3f64kGiSWoRi9EJawJWCzJfUQRT
// SIG // hDL4zxI2pYc1wnPp7Q695bHqwZ02eaOBudh/IfEkGe0O
// SIG // fj6IS3oyZsJP1yatcm4kBqIH6db1+weM4q46NhAfAf07
// SIG // 0zF6F+IpUHyhtMbQg5+QHfOuyBzrt67CiMJSKcJ3nMVy
// SIG // fNlnv6yvttYzLK3wS+0QwJUibLYJMI6FGcSuRxKlq6Rj
// SIG // OhK9L3QOjh0VCM11rHM11ZmN0euJbbBCVfQEufOLNkG8
// SIG // 8MFCUNE10SSbM/Og/CbTko0M5wbVvQJ6CqLKjtHSoeoA
// SIG // GPeeX24f5cPYyTcKlbM6LoUdO2P5JSdI5s1JF/On6LiU
// SIG // T50adpRstZajbYEeX/N7RvSbkn0djD3BvT2Of3Wf9gIe
// SIG // aQIHbv1J2O/P5QOPQiVo8+0AKm6M0TKOduihhKxAt/6Y
// SIG // yk17Fv3RIdjT6wiL2qRIEsgOJp3fILw4mQRPu3spRfak
// SIG // SoQe5N0e4HWFf8WW2ZL0+c83Qzh3VtEPI6Y2e2BO/eWh
// SIG // TYbIbHpqYDfAtAYtaYIde87ZymXG3MO2wUjhL9HvSQzj
// SIG // oquq+OoUmvfBUcB2e5L6QCHO6qTO7WowggdxMIIFWaAD
// SIG // AgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3
// SIG // DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYD
// SIG // VQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBB
// SIG // dXRob3JpdHkgMjAxMDAeFw0yMTA5MzAxODIyMjVaFw0z
// SIG // MDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBD
// SIG // QSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
// SIG // CgKCAgEA5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9Kp
// SIG // bE51yMo1V/YBf2xK4OK9uT4XYDP/XE/HZveVU3Fa4n5K
// SIG // Wv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTz
// SIG // xXb1hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9
// SIG // cmmvHaus9ja+NSZk2pg7uhp7M62AW36MEBydUv626GIl
// SIG // 3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3K
// SIG // Ni1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3t
// SIG // pK56KTesy+uDRedGbsoy1cCGMFxPLOJiss254o2I5Jas
// SIG // AUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF803RKJ
// SIG // 1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHo
// SIG // vwUDo9Fzpk03dJQcNIIP8BDyt0cY7afomXw/TNuvXsLz
// SIG // 1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahhaYQFzymei
// SIG // XtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8w
// SIG // dJGUlNi5UPkLiWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFd
// SIG // Etsluq9QBXpsxREdcu+N+VLEhReTwDwV2xo3xwgVGD94
// SIG // q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0w
// SIG // ggHZMBIGCSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGC
// SIG // NxUCBBYEFCqnUv5kxJq+gpE8RjUpzxD/LwTuMB0GA1Ud
// SIG // DgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAE
// SIG // VTBTMFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIB
// SIG // FjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3Bz
// SIG // L0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYI
// SIG // KwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBD
// SIG // AEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQFMAMBAf8w
// SIG // HwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQw
// SIG // VgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNy
// SIG // b3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvTWljUm9v
// SIG // Q2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEB
// SIG // BE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXRf
// SIG // MjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcNAQELBQADggIB
// SIG // AJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEG
// SIG // k5c9MTO1OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi
// SIG // 7ulmZzpTTd2YurYeeNg2LpypglYAA7AFvonoaeC6Ce57
// SIG // 32pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OO
// SIG // PcbzaN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECW
// SIG // OKz3+SmJw7wXsFSFQrP8DJ6LGYnn8AtqgcKBGUIZUnWK
// SIG // NsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3m
// SIG // Sj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSw
// SIG // ethQ/gpY3UA8x1RtnWN0SCyxTkctwRQEcb9k+SS+c23K
// SIG // jgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxkoJLo4
// SIG // S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFE
// SIG // fnyhYWxz/gq77EFmPWn9y8FBSX5+k77L+DvktxW/tM4+
// SIG // pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC4822rpM+Zv/
// SIG // Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7t
// SIG // fqAxM328y+l7vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJt
// SIG // pQUQwXEGahC0HVUzWLOhcGbyoYIDVjCCAj4CAQEwggEB
// SIG // oYHZpIHWMIHTMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYD
// SIG // VQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRpb25z
// SIG // IExpbWl0ZWQxJzAlBgNVBAsTHm5TaGllbGQgVFNTIEVT
// SIG // Tjo0MzFBLTA1RTAtRDk0NzElMCMGA1UEAxMcTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsO
// SIG // AwIaAxUA94Z+bUJn+nKwBvII6sg0Ny7aPDaggYMwgYCk
// SIG // fjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDANBgkq
// SIG // hkiG9w0BAQsFAAIFAOrGlqkwIhgPMjAyNDEwMjUyMjE0
// SIG // MDFaGA8yMDI0MTAyNjIyMTQwMVowdDA6BgorBgEEAYRZ
// SIG // CgQBMSwwKjAKAgUA6saWqQIBADAHAgEAAgI23TAHAgEA
// SIG // AgITMTAKAgUA6sfoKQIBADA2BgorBgEEAYRZCgQCMSgw
// SIG // JjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIB
// SIG // AAIDAYagMA0GCSqGSIb3DQEBCwUAA4IBAQA0516+hRt8
// SIG // IvpoZ4ib1Rxd01Jgb74zinR8eCyghNBisZxjDrf/DmYF
// SIG // WXh8WfBlc0sACrX8Pl0SHrlyMXbxtzTJAIEa8Ro8uaEG
// SIG // O37v2WsifvCh1dVuO3z9Tgy5YDgu+N889L0qXQ3OyRrD
// SIG // YT0uPf10ypF6waniDfv4jEB8zfvQGAHT7DKPafC/yJmY
// SIG // 2SU6aYTw6nrTTy6dqyOvNpuW9Bud/pehWZksn0T7cXzt
// SIG // yOj5hnMXYtrLQdTvvKAvqhkQSMz+O/LeofhpaXvLaMrG
// SIG // qzbEGnrgG181C5zf/gOXhk3nL+ENCuBAnZrgIeAoqMVR
// SIG // kbkPFv+gThuNylUHVgS17/t6MYIEDTCCBAkCAQEwgZMw
// SIG // fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWlj
// SIG // cm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAH6
// SIG // +ztE03czxtMAAQAAAfowDQYJYIZIAWUDBAIBBQCgggFK
// SIG // MBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkq
// SIG // hkiG9w0BCQQxIgQgdFwfd5aM4xLDZNztgEbf1xz9LGNo
// SIG // s0kL4WCef4KaKXYwgfoGCyqGSIb3DQEJEAIvMYHqMIHn
// SIG // MIHkMIG9BCB98n8tya8+B2jjU/dpJRIwHwHHpco5ogNS
// SIG // tYocbkOeVjCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwAhMzAAAB+vs7RNN3M8bTAAEAAAH6MCIE
// SIG // IPv8Thbz8a+rxOY4kT9PipccOWPQvgTiKDCdyEKjPPnO
// SIG // MA0GCSqGSIb3DQEBCwUABIICAJKLwdpf8SHo/7JFa4NB
// SIG // Cei/13rCGMdhtTdPKOw41WpzbDKPGU0Pse92enf9gwr1
// SIG // mlgabb8W1CfzbdGUEa84ZWWColLkjJfSwhPzyLEFwZLR
// SIG // YNkc6Bah1d+A223Pgdwtclofb9+78Umn8uHR2hB8h1fM
// SIG // xRm5OLjQmA0OFwV+eZddYQYOxAT1b8zANTuH7frBnhbf
// SIG // Up2th/cNGqfSIdcfQxj3HuEA0b0p/kHcvl5b2X6lB+tU
// SIG // tKj90z63w7L7M2uqb4BHJ0pxLXrUWKG6GOBY0s5POl+m
// SIG // v6cb4KNN622dvfA8walM1oLviq7GCOpDHaVT9Okvj4NT
// SIG // QqMorMBe1EVmFxB1gt8+fpVMB//n8nPD5Mn2CEc1oyeX
// SIG // mxzRK2EjcL3Jk4kpYL/M8Yf7xDCTeok7O/f7l95+2tIl
// SIG // uRyatv2GIVNkBGKUTPTL1aLVYwJfuPPZv87xzuLcANai
// SIG // 5BfZ1hxnt+U+L/yDdSQulC9iP5ttr3XECnFCr4F8KunK
// SIG // 4fYHDaihZNmoUXuubulZ2ae1up1zFgsQ24ZDO/FZIFGn
// SIG // 9C/PBGW/D8Wl/P5E7iMNzZWjAWp2HRA5WZH1pPf7q5sz
// SIG // uEw+MqOgnab7VrwCoaEN0VbHT7NrCOHPswRss0m6GF8s
// SIG // dcBh+iSbyKY6VdM7EjGp3FF9XNSgUTZosmU7s/govFh5
// SIG // lFsR
// SIG // End signature block
